==> qtjambi-quick-debuginfo-macos-6.5.4.jar: sources/QtJambiQuick/QQuickAsyncImageProvider_shell.h <==
#ifndef QQUICKASYNCIMAGEPROVIDER_SHELL_H
#define QQUICKASYNCIMAGEPROVIDER_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtQuick/qquickimageprovider.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qsize.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtGui/qimage.h>
#include <QtGui/qpixmap.h>
#include <QtQml/qqmlengine.h>
#include <QtJambi/RegistryAPI>


class QQuickAsyncImageProvider_shell : public QQuickAsyncImageProvider, public QtJambiShellInterface
{
public:
    QQuickAsyncImageProvider_shell();
    ~QQuickAsyncImageProvider_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    QQmlImageProviderBase::Flags flags() const override;
    QQmlImageProviderBase::ImageType imageType() const override;
    QImage requestImage(const QString& id0, QSize* size1, const QSize& requestedSize2) override;
    QQuickImageResponse* requestImageResponse(const QString& id0, const QSize& requestedSize1) override;
    QPixmap requestPixmap(const QString& id0, QSize* size1, const QSize& requestedSize2) override;
    QQuickTextureFactory* requestTexture(const QString& id0, QSize* size1, const QSize& requestedSize2) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QQuickAsyncImageProvider_access : public QQuickAsyncImageProvider
{
    jobject __qt_requestImageResponse_cref_QString_cref_QSize(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring id0, QtJambiNativeID requestedSize1);
};

#endif // QQUICKASYNCIMAGEPROVIDER_SHELL_H

==> qtjambi-quick-debuginfo-macos-6.5.7.jar: sources/QtJambiQuick/QQuickAsyncImageProvider_shell.h <==
#ifndef QQUICKASYNCIMAGEPROVIDER_SHELL_H
#define QQUICKASYNCIMAGEPROVIDER_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtQuick/qquickimageprovider.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qsize.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtGui/qimage.h>
#include <QtGui/qpixmap.h>
#include <QtQml/qqmlengine.h>
#include <QtJambi/RegistryAPI>


class QQuickAsyncImageProvider_shell : public QQuickAsyncImageProvider, public QtJambiShellInterface
{
public:
    QQuickAsyncImageProvider_shell();
    ~QQuickAsyncImageProvider_shell() override;
private:
    QtJambiShell* __shell() const override final;
    friend class QQuickAsyncImageProvider_mshell;
    friend class QQuickAsyncImageProvider_oshell;
};


class QQuickAsyncImageProvider_mshell : public QQuickAsyncImageProvider_shell
{
public:
    using QQuickAsyncImageProvider_shell::QQuickAsyncImageProvider_shell;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
};


class QQuickAsyncImageProvider_oshell : public QQuickAsyncImageProvider_mshell
{
public:
    using QQuickAsyncImageProvider_mshell::QQuickAsyncImageProvider_mshell;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    QQmlImageProviderBase::Flags flags() const override;
    QQmlImageProviderBase::ImageType imageType() const override;
    QImage requestImage(const QString& id0, QSize* size1, const QSize& requestedSize2) override;
    QQuickImageResponse* requestImageResponse(const QString& id0, const QSize& requestedSize1) override;
    QPixmap requestPixmap(const QString& id0, QSize* size1, const QSize& requestedSize2) override;
    QQuickTextureFactory* requestTexture(const QString& id0, QSize* size1, const QSize& requestedSize2) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
private:
    jmethodID __shell_javaMethod(int pos) const;
};

struct QQuickAsyncImageProvider_access : public QQuickAsyncImageProvider
{
    jobject __qt_requestImageResponse_cref_QString_cref_QSize(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring id0, QtJambiNativeID requestedSize1);
};

#endif // QQUICKASYNCIMAGEPROVIDER_SHELL_H
